@@ -1,6 +1,19 @@
 # vim: set fileencoding=utf-8 :
 #
 # (C) 2006,2007,2008,2011 Guido Guenther <agx@sigxcpu.org>
+#    This program is free software; you can redistribute it and/or modify
+#    it under the terms of the GNU General Public License as published by
+#    the Free Software Foundation; either version 2 of the License, or
+#    (at your option) any later version.
+#
+#    This program is distributed in the hope that it will be useful,
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#    GNU General Public License for more details.
+#
+#    You should have received a copy of the GNU General Public License
+#    along with this program; if not, write to the Free Software
+#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 """provides git repository related helpers"""
 
 import re
@@ -13,7 +26,7 @@ import dateutil.parser
 import calendar
 
 class GitRepositoryError(Exception):
-    """Exception thrown by GitRepository"""
+    """Exception thrown by L{GitRepository}"""
     pass
 
 
@@ -113,7 +126,7 @@ class GitRepository(object):
         You only need to use this funciton if you also need to check for legacy
         tags.
 
-        @param pattern: tag pattern
+        @param format: tag pattern
         @param version: debian version number
         @return: sha1 of the version tag
         """
@@ -253,28 +266,35 @@ class GitRepository(object):
         else:
             return []
 
-    def commits(self, since=None, until=None, paths=None, options=None):
-        """get commits from start to end touching pathds"""
+    def commits(self, since=None, until=None, paths=None, options=None,
+                first_parent=False):
+        """
+        get commits from since to until touching paths
 
-        if since or until:
-            range = ['%s..%s' % (since, until)]
-        else:
-            range = []
+        @param options: list of options past to git log
+        @type  options: list of strings
+        """
+
+        args = ['--pretty=format:%H']
+
+        if options:
+            args += options
+
+        if first_parent:
+            args += [ "--first-parent" ]
+
+        if since and until:
+            args += ['%s..%s' % (since, until)]
 
         if paths:
-           paths = [ "--", paths ]
-        else:
-            paths = []
+            args += [ "--", paths ]
 
-        commits, ret = self.__git_getoutput('log',
-                                            ['--pretty=format:%H'] +
-                                            options +
-                                            range +
-                                            paths)
+        commits, ret = self.__git_getoutput('log', args)
         if ret:
+            where = " on %s" % paths if paths else ""
             raise GitRepositoryError, ("Error getting commits %s..%s%s" %
-                        (since, until,["", " on %s" % paths][len(paths) > 0] ))
-        return [ commit.strip() for commit in commits[::-1] ]
+                        (since, until, where))
+        return [ commit.strip() for commit in commits ]
 
     def show(self, id):
         """git-show id"""
@@ -384,13 +404,17 @@ class GitRepository(object):
                    author={}, committer={}):
         """Replace the current tip of branch 'branch' with the contents from 'unpack_dir'
            @param unpack_dir: content to add
+           @type unpack_dir: string
            @param msg: commit message to use
+           @type msg: string
            @param branch: branch to add the contents of unpack_dir to
-           @param parents: additional parents of this commit
-           @param author: commit with author information from author
+           @type branch: string
+           @param other_parents: additional parents of this commit
+           @type other_parents: list string
+           @param author: author information to use for commit
            @type author: dict with keys 'name', 'email', 'date'
-           @param committer_author: commit with committer information from committer
-           @type comitter: dict with keys 'name', 'email', 'date'"""
+           @param committer: committer information to use for commit
+           @type committer: dict with keys 'name', 'email', 'date'"""
 
         self.__check_path()
         git_index_file = os.path.join(self.path, '.git', 'gbp_index')
@@ -465,18 +489,22 @@ class GitRepository(object):
             return False
 
     def format_patches(self, start, end, output_dir):
+        """
+        Output the commits between start and end as patches in output_dir
+        """
         options = [ '-N', '-k', '-o', output_dir, '%s...%s' % (start, end) ]
         output, ret = self.__git_getoutput('format-patch', options)
         return [ line.strip() for line in output ]
 
-    def apply_patch(self, patch, index=True, context=None):
+    def apply_patch(self, patch, index=True, context=None, strip=None):
         """Apply a patch using git apply"""
-
         args = []
         if context:
             args += [ '-C', context ]
         if index:
             args.append("--index")
+        if strip:
+            args += [ '-p', strip ]
         args.append(patch)
         GitCommand("apply", args)()
 
@@ -489,7 +517,7 @@ class GitRepository(object):
 
 
     def has_submodules(self):
-        """Does the repo have submodules"""
+        """Does the repo have submodules?"""
         if os.path.exists('.gitmodules'):
             return True
         else:
@@ -628,6 +656,7 @@ def create_repo(path):
 
 def build_tag(format, version):
     """Generate a tag from a given format and a version
+
     >>> build_tag("debian/%(version)s", "0:0~0")
     'debian/0%0_0'
     """
@@ -636,6 +665,7 @@ def build_tag(format, version):
 
 def __sanitize_version(version):
     """sanitize a version so git accepts it as a tag
+
     >>> __sanitize_version("0.0.0")
     '0.0.0'
     >>> __sanitize_version("0.0~0")
@@ -650,6 +680,7 @@ def __sanitize_version(version):
 
 def tag_to_version(tag, format):
     """Extract the version from a tag
+
     >>> tag_to_version("upstream/1%2_3-4", "upstream/%(version)s")
     '1:2~3-4'
     >>> tag_to_version("foo/2.3.4", "foo/%(version)s")
@@ -667,6 +698,7 @@ def tag_to_version(tag, format):
 
 def rfc822_date_to_git(rfc822_date):
     """Parse a date in RFC822 format, and convert to a 'seconds tz' string.
+
     >>> rfc822_date_to_git('Thu, 1 Jan 1970 00:00:01 +0000')
     '1 +0000'
     >>> rfc822_date_to_git('Thu, 20 Mar 2008 01:12:57 -0700')
